@@ -56,7 +56,7 @@
 
 
 char *Release = RELEASE,
-     *Version = "@(#)netstat.c 1.1.27 (16/07/94)";
+     *Version = "@(#)netstat.c 1.1.79 (09/01/95)";
 #define Signature "(c) 1993, Fred Baumgarten <dc6iq@insu1.etec.uni-karlsruhe.de>"
 
 
@@ -355,7 +355,7 @@ tcp_info(void)
 			break;
 
 		default:
-			tcp_state = "?? ()";
+			tcp_state = "UNKNOWN";
 			break;
 	}
 	strcpy(local_addr, ap->sprint((struct sockaddr *)&localaddr, flag_not));
@@ -862,6 +862,7 @@ iface_info(void)
   ifc.ifc_buf = buff;
   if (ioctl(skfd, SIOCGIFCONF, &ifc) < 0) {
 	perror("SIOCGIFCONF");
+	close(skfd);
 	return(E_IOCTL);
   }
 
@@ -877,6 +878,7 @@ iface_info(void)
 	if (((ife.flags & IFF_UP) == 0) && !flag_all) continue;
 	ife_print(&ife);
   }
+  close(skfd);
   return(0);
 }
 
